==> spring-2.0-sources.jar: org/springframework/test/jpa/OrmXmlOverridingShadowingClassLoader.java <==
/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.test.jpa;

import java.util.LinkedList;
import java.util.List;

import org.springframework.instrument.classloading.ResourceOverridingShadowingClassLoader;

/**
 * Subclass of ShadowingClassLoader that overrides attempts to
 * locate <code>orm.xml</code>.
 *
 * <p>This class must <b>not</b> be an inner class of AbstractJpaTests
 * to avoid it being loaded until first used.
 *
 * @author Rod Johnson
 * @author Adrian Colyer
 * @since 2.0
 */
class OrmXmlOverridingShadowingClassLoader extends ResourceOverridingShadowingClassLoader {
	
	private List<String> providerPrefixes = new LinkedList<String>(); {
		// Automatically exclude classes from these well-known persistence providers
		providerPrefixes.add("oracle.toplink.essentials");
		

		// Do NOT exclude Hibernate classes --
		// this causes class casts due to use of
		// CGLIB by Hibernate
		
		// Same goes for OpenJPA which will not enhance the domain classes
	}
	

	public OrmXmlOverridingShadowingClassLoader(ClassLoader loader, String realOrmXmlLocation) {
		super(loader);
		override("META-INF/orm.xml", realOrmXmlLocation);
	}
	
	@Override
	protected boolean isClassNameExcludedFromShadowing(String className) {
		for (String providerPrefix : providerPrefixes) {
			if (className.startsWith(providerPrefix)) {
				return true;
			}
		}
		
		// Also do not shadow JUnit infrastructure
		if (className.startsWith("junit")) {
			return true;
		}
		
		return false;
	}
	
	
}

==> spring-2.0.2-sources.jar: org/springframework/test/jpa/OrmXmlOverridingShadowingClassLoader.java <==
/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.test.jpa;

import java.util.LinkedList;
import java.util.List;

import org.springframework.instrument.classloading.ResourceOverridingShadowingClassLoader;

/**
 * Subclass of ShadowingClassLoader that overrides attempts to
 * locate <code>orm.xml</code>.
 *
 * <p>This class must <b>not</b> be an inner class of AbstractJpaTests
 * to avoid it being loaded until first used.
 *
 * @author Rod Johnson
 * @author Adrian Colyer
 * @since 2.0
 */
class OrmXmlOverridingShadowingClassLoader extends ResourceOverridingShadowingClassLoader {
	
	/**
	 * Default location of the <code>orm.xml</code> file in the class path:
	 * "META-INF/orm.xml"
	 */
	public static final String DEFAULT_ORM_XML_LOCATION = "META-INF/orm.xml";


	private final List<String> providerPrefixes = new LinkedList<String>();

	{
		// Automatically exclude classes from these well-known persistence providers.
		this.providerPrefixes.add("oracle.toplink.essentials");
		
		// Do NOT exclude Hibernate classes --
		// this causes class casts due to use of CGLIB by Hibernate.
		// Same goes for OpenJPA which will not enhance the domain classes.
	}
	

	public OrmXmlOverridingShadowingClassLoader(ClassLoader loader, String realOrmXmlLocation) {
		super(loader);
		override(DEFAULT_ORM_XML_LOCATION, realOrmXmlLocation);
	}
	
	@Override
	protected boolean isClassNameExcludedFromShadowing(String className) {
		for (String providerPrefix : providerPrefixes) {
			if (className.startsWith(providerPrefix)) {
				return true;
			}
		}
		
		// Also do not shadow JUnit infrastructure.
		if (className.startsWith("junit")) {
			return true;
		}
		
		return false;
	}
	
}
